"""Face detection."""
from .cascade import HAARCascade as HAARFaceDetector
from .cascade import LBPCascade as LBPFaceDetector
from .ssd import SSDFaceDetector